Assorted spelling fixes

Francois Gouget fgouget at free.fr
Thu Feb 10 06:08:38 CST 2005


Mostly fixing the spelling of 'nonexistent' this time around. 
http://dictionary.reference.com/search?q=nonexistent


Changelog:

  * aclocal.m4
    dlls/advapi32/tests/crypt.c
    dlls/comctl32/tests/imagelist.c
    dlls/dplayx/name_server.c
    dlls/kernel/tests/directory.c
    dlls/kernel/tests/file.c
    dlls/kernel/tests/mailslot.c
    dlls/kernel/tests/path.c
    dlls/lzexpand/tests/lzexpand_main.c
    dlls/mapi32/tests/prop.c
    dlls/msi/table.c
    dlls/msrle32/msrle32.c
    dlls/msvcrt/environ.c
    dlls/msvcrt/tests/environ.c
    dlls/quartz/acmwrapper.c
    dlls/rsaenh/rsaenh.c
    dlls/shell32/pidl.c
    dlls/shell32/shellpath.c
    dlls/shell32/tests/shellpath.c
    dlls/shell32/tests/shlfileop.c
    dlls/shlwapi/tests/clist.c
    dlls/wined3d/directx.c
    dlls/winedos/ppdev.c
    documentation/configuring.sgml
    programs/wcmd/En.rc
    programs/wcmd/Ru.rc
    programs/wcmd/Si.rc
    tools/winebuild/spec32.c

    Assorted spelling fixes.


-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
         War doesn't determine who's right.  War determines who's left.
-------------- next part --------------
Index: aclocal.m4
===================================================================
RCS file: /var/cvs/wine/aclocal.m4,v
retrieving revision 1.13
diff -u -p -r1.13 aclocal.m4
--- aclocal.m4	22 Sep 2004 19:17:55 -0000	1.13
+++ aclocal.m4	27 Jan 2005 08:19:10 -0000
@@ -111,7 +111,7 @@ else
 fi
 rm -f conf$$ conf$$.file])
 
-dnl **** Create non-existent directories from config.status ****
+dnl **** Create nonexistent directories from config.status ****
 dnl
 dnl Usage: WINE_CONFIG_EXTRA_DIR(dirname)
 dnl
Index: dlls/advapi32/tests/crypt.c
===================================================================
RCS file: /var/cvs/wine/dlls/advapi32/tests/crypt.c,v
retrieving revision 1.14
diff -u -p -r1.14 crypt.c
--- dlls/advapi32/tests/crypt.c	4 Jan 2005 20:31:53 -0000	1.14
+++ dlls/advapi32/tests/crypt.c	27 Jan 2005 08:15:32 -0000
@@ -29,7 +29,7 @@
 #include "wine/test.h"
 
 static const char szRsaBaseProv[] = MS_DEF_PROV_A;
-static const char szNonExistentProv[] = "Wine Non Existent Cryptographic Provider v11.2";
+static const char szNonExistentProv[] = "Wine Nonexistent Cryptographic Provider v11.2";
 static const char szKeySet[] = "wine_test_keyset";
 static const char szBadKeySet[] = "wine_test_bad_keyset";
 #define NON_DEF_PROV_TYPE 999
Index: dlls/comctl32/tests/imagelist.c
===================================================================
RCS file: /var/cvs/wine/dlls/comctl32/tests/imagelist.c,v
retrieving revision 1.10
diff -u -p -r1.10 imagelist.c
--- dlls/comctl32/tests/imagelist.c	13 Dec 2004 21:19:02 -0000	1.10
+++ dlls/comctl32/tests/imagelist.c	27 Jan 2005 08:15:54 -0000
@@ -307,9 +307,9 @@ static BOOL DoTest1(void)
     ok(hicon3 != 0, "no hicon3\n");
 
     /* remove when nothing exists */
-    ok(!ImageList_Remove(himl,0),"removed non-existent icon\n");
+    ok(!ImageList_Remove(himl,0),"removed nonexistent icon\n");
     /* removing everything from an empty imagelist should succeed */
-    ok(ImageList_RemoveAll(himl),"removed non-existent icon\n");
+    ok(ImageList_RemoveAll(himl),"removed nonexistent icon\n");
 
     /* add three */
     ok(0==ImageList_AddIcon(himl, hicon1),"failed to add icon1\n");
@@ -317,7 +317,7 @@ static BOOL DoTest1(void)
     ok(2==ImageList_AddIcon(himl, hicon3),"failed to add icon3\n");
 
     /* remove an index out of range */
-    ok(!ImageList_Remove(himl,4711),"removed non-existent icon\n");
+    ok(!ImageList_Remove(himl,4711),"removed nonexistent icon\n");
 
     /* remove three */
     ok(ImageList_Remove(himl,0),"can't remove 0\n");
@@ -325,7 +325,7 @@ static BOOL DoTest1(void)
     ok(ImageList_Remove(himl,0),"can't remove 0\n");
 
     /* remove one extra */
-    ok(!ImageList_Remove(himl,0),"removed non-existent icon\n");
+    ok(!ImageList_Remove(himl,0),"removed nonexistent icon\n");
 
     /* destroy it */
     ok(ImageList_Destroy(himl),"destroy imagelist failed\n");
Index: dlls/dplayx/name_server.c
===================================================================
RCS file: /var/cvs/wine/dlls/dplayx/name_server.c,v
retrieving revision 1.16
diff -u -p -r1.16 name_server.c
--- dlls/dplayx/name_server.c	29 Sep 2003 20:12:05 -0000	1.16
+++ dlls/dplayx/name_server.c	27 Jan 2005 08:16:06 -0000
@@ -267,7 +267,7 @@ void NS_InvalidateSessionCache( LPVOID l
 
   if( lpCache == NULL )
   {
-    ERR( ": invalidate non existent cache\n" );
+    ERR( ": invalidate nonexistent cache\n" );
     return;
   }
 
Index: dlls/kernel/tests/directory.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/directory.c,v
retrieving revision 1.14
diff -u -p -r1.14 directory.c
--- dlls/kernel/tests/directory.c	20 Dec 2004 19:27:07 -0000	1.14
+++ dlls/kernel/tests/directory.c	27 Jan 2005 08:16:22 -0000
@@ -213,7 +213,7 @@ static void test_CreateDirectoryA(void)
     lstrcatA(tmpdir, "Please Remove Me/Please Remove Me");
     ret = CreateDirectoryA(tmpdir, NULL);
     ok(ret == FALSE && GetLastError() == ERROR_PATH_NOT_FOUND, 
-      "CreateDirectoryA with multiple non-existent directories in path should fail\n");
+      "CreateDirectoryA with multiple nonexistent directories in path should fail\n");
     ret = RemoveDirectoryA(tmpdir);
     
 }
@@ -285,7 +285,7 @@ static void test_CreateDirectoryW(void)
     lstrcatW(tmpdir, tmp_dir_name);
     ret = CreateDirectoryW(tmpdir, NULL);
     ok(ret == FALSE && GetLastError() == ERROR_PATH_NOT_FOUND, 
-      "CreateDirectoryW with multiple non-existent directories in path should fail\n");
+      "CreateDirectoryW with multiple nonexistent directories in path should fail\n");
     ret = RemoveDirectoryW(tmpdir);
 }
 
Index: dlls/kernel/tests/file.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/file.c,v
retrieving revision 1.45
diff -u -p -r1.45 file.c
--- dlls/kernel/tests/file.c	27 Dec 2004 17:26:38 -0000	1.45
+++ dlls/kernel/tests/file.c	27 Jan 2005 08:16:34 -0000
@@ -690,7 +690,7 @@ static void test_CreateFileW(void)
     ok(hFile == INVALID_HANDLE_VALUE && GetLastError() == ERROR_PATH_NOT_FOUND,
        "CreateFileW(\"\") returned ret=%p error=%ld\n",hFile,GetLastError());
 
-    /* test the result of opening a non-existent driver name */
+    /* test the result of opening a nonexistent driver name */
     hFile = CreateFileW(bogus, 0, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL,
                         OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
     ok(hFile == INVALID_HANDLE_VALUE && GetLastError() == ERROR_FILE_NOT_FOUND,
Index: dlls/kernel/tests/mailslot.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/mailslot.c,v
retrieving revision 1.4
diff -u -p -r1.4 mailslot.c
--- dlls/kernel/tests/mailslot.c	9 Aug 2004 23:42:19 -0000	1.4
+++ dlls/kernel/tests/mailslot.c	27 Jan 2005 08:16:46 -0000
@@ -51,7 +51,7 @@ static int mailslot_test()
     /* open a mailslot that doesn't exist */
     hWriter = CreateFile(szmspath, GENERIC_READ|GENERIC_WRITE,
                              FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL);
-    ok( hWriter == INVALID_HANDLE_VALUE, "non-existing mailslot\n");
+    ok( hWriter == INVALID_HANDLE_VALUE, "nonexistent mailslot\n");
 
     /* open a mailslot without the right name */
     hSlot = CreateMailslot( "blah", 0, 0, NULL );
Index: dlls/lzexpand/tests/lzexpand_main.c
===================================================================
RCS file: /var/cvs/wine/dlls/lzexpand/tests/lzexpand_main.c,v
retrieving revision 1.3
diff -u -p -r1.3 lzexpand_main.c
--- dlls/lzexpand/tests/lzexpand_main.c	28 Jan 2005 14:02:52 -0000	1.3
+++ dlls/lzexpand/tests/lzexpand_main.c	29 Jan 2005 17:54:54 -0000
@@ -80,7 +80,7 @@ static void test_lzopenfile(void)
   DWORD retval;
   INT file;
 
-  /* Check for non-existent file. */
+  /* Check for nonexistent file. */
   file = LZOpenFile("badfilename_", &test, OF_READ);
   ok(file == LZERROR_BADINHANDLE, 
      "LZOpenFile succeeded on nonexistent file\n");
Index: dlls/msi/table.c
===================================================================
RCS file: /var/cvs/wine/dlls/msi/table.c,v
retrieving revision 1.29
diff -u -p -r1.29 table.c
--- dlls/msi/table.c	8 Feb 2005 13:44:25 -0000	1.29
+++ dlls/msi/table.c	8 Feb 2005 18:14:37 -0000
@@ -408,7 +408,7 @@ UINT read_table_from_storage( MSIDATABAS
 
     TRACE("%s\n",debugstr_w(name));
 
-    /* non-existing tables should be interpreted as empty tables */
+    /* nonexistent tables should be interpreted as empty tables */
     t = HeapAlloc( GetProcessHeap(), 0, 
                    sizeof (MSITABLE) + lstrlenW(name)*sizeof (WCHAR) );
     if( !t )
Index: dlls/msrle32/msrle32.c
===================================================================
RCS file: /var/cvs/wine/dlls/msrle32/msrle32.c,v
retrieving revision 1.11
diff -u -p -r1.11 msrle32.c
--- dlls/msrle32/msrle32.c	9 Jan 2005 16:52:51 -0000	1.11
+++ dlls/msrle32/msrle32.c	27 Jan 2005 08:14:24 -0000
@@ -157,7 +157,7 @@ static BOOL  isSupportedDIB(LPCBITMAPINF
   if (DIBWIDTHBYTES(*lpbi) * (DWORD)lpbi->biHeight >= (1UL << 31) - 1)
     return FALSE; /* image too big ! */
 
-  /* check for non-existent colortable for hi- and true-color DIB's */
+  /* check for nonexistent colortable for hi- and true-color DIB's */
   if (lpbi->biBitCount >= 15 && lpbi->biClrUsed > 0)
     return FALSE;
 
Index: dlls/msvcrt/environ.c
===================================================================
RCS file: /var/cvs/wine/dlls/msvcrt/environ.c,v
retrieving revision 1.13
diff -u -p -r1.13 environ.c
--- dlls/msvcrt/environ.c	19 Jul 2004 21:23:02 -0000	1.13
+++ dlls/msvcrt/environ.c	27 Jan 2005 08:14:12 -0000
@@ -93,7 +93,7 @@ int _putenv(const char *str)
 
  ret = SetEnvironmentVariableA(name, value[0] ? value : NULL) ? 0 : -1;
 
- /* _putenv returns success on deletion of non-existent variable, unlike [Rtl]SetEnvironmentVariable */
+ /* _putenv returns success on deletion of nonexistent variable, unlike [Rtl]SetEnvironmentVariable */
  if ((ret == -1) && (GetLastError() == ERROR_ENVVAR_NOT_FOUND)) ret = 0;
 
  /* Update the __p__environ array only when already initialized */
@@ -129,7 +129,7 @@ int _wputenv(const MSVCRT_wchar_t *str)
 
  ret = SetEnvironmentVariableW(name, value[0] ? value : NULL) ? 0 : -1;
 
- /* _putenv returns success on deletion of non-existent variable, unlike [Rtl]SetEnvironmentVariable */
+ /* _putenv returns success on deletion of nonexistent variable, unlike [Rtl]SetEnvironmentVariable */
  if ((ret == -1) && (GetLastError() == ERROR_ENVVAR_NOT_FOUND)) ret = 0;
 
  /* Update the __p__environ array only when already initialized */
Index: dlls/msvcrt/tests/environ.c
===================================================================
RCS file: /var/cvs/wine/dlls/msvcrt/tests/environ.c,v
retrieving revision 1.1
diff -u -p -r1.1 environ.c
--- dlls/msvcrt/tests/environ.c	19 Jul 2004 21:23:02 -0000	1.1
+++ dlls/msvcrt/tests/environ.c	27 Jan 2005 08:13:59 -0000
@@ -23,7 +23,7 @@
 
 START_TEST(environ)
 {
-    ok( _putenv("cat=") == 0, "_putenv failed on deletion of non-existent environment variable\n" );
+    ok( _putenv("cat=") == 0, "_putenv failed on deletion of nonexistent environment variable\n" );
     ok( _putenv("cat=dog") == 0, "failed setting cat=dog\n" );
     ok( strcmp(getenv("cat"), "dog") == 0, "getenv did not return 'dog'\n" );
     ok( _putenv("cat=") == 0, "failed deleting cat\n" );
Index: dlls/quartz/acmwrapper.c
===================================================================
RCS file: /var/cvs/wine/dlls/quartz/acmwrapper.c,v
retrieving revision 1.1
diff -u -p -r1.1 acmwrapper.c
--- dlls/quartz/acmwrapper.c	1 Feb 2005 14:22:00 -0000	1.1
+++ dlls/quartz/acmwrapper.c	2 Feb 2005 14:38:33 -0000
@@ -197,7 +197,7 @@ static HRESULT ACMWrapper_ConnectInput(T
             This->has = drv;
 
 	    if ((res = acmStreamSize(drv, OUTPUT_BUFFER_SIZE, &This->max_size, ACM_STREAMSIZEF_DESTINATION))) {
-		ERR("Cannot retreive input buffer size error %d!\n", res);
+		ERR("Cannot retrieve input buffer size error %d!\n", res);
 		This->max_size = INPUT_BUFFER_SIZE;
 	    }
 
Index: dlls/rsaenh/rsaenh.c
===================================================================
RCS file: /var/cvs/wine/dlls/rsaenh/rsaenh.c,v
retrieving revision 1.21
diff -u -p -r1.21 rsaenh.c
--- dlls/rsaenh/rsaenh.c	9 Feb 2005 22:25:09 -0000	1.21
+++ dlls/rsaenh/rsaenh.c	9 Feb 2005 23:14:46 -0000
@@ -3076,7 +3076,7 @@ BOOL WINAPI RSAENH_CPGetUserKey(HCRYPTPR
 
     if (*phUserKey == (HCRYPTKEY)INVALID_HANDLE_VALUE)
     {
-        /* MSDN: dwKeySpec parameter specifies non existent key */
+        /* MSDN: dwKeySpec parameter specifies nonexistent key */
         SetLastError(NTE_NO_KEY);
         return FALSE;
     }
Index: dlls/shell32/pidl.c
===================================================================
RCS file: /var/cvs/wine/dlls/shell32/pidl.c,v
retrieving revision 1.124
diff -u -p -r1.124 pidl.c
--- dlls/shell32/pidl.c	23 Dec 2004 17:12:07 -0000	1.124
+++ dlls/shell32/pidl.c	27 Jan 2005 08:13:48 -0000
@@ -977,7 +977,7 @@ LPITEMIDLIST WINAPI ILCreateFromPathAW (
  *  IShellFolder uses that FileSystem Bind Data object of the BindContext
  *  to pass data about the current path element to the next object. This
  *  is used to avoid having to verify the current path element on disk, so
- *  that creating an ItemIDList from a non-existent path still can work.
+ *  that creating an ItemIDList from a nonexistent path still can work.
  */
 static HRESULT WINAPI _ILParsePathW(LPCWSTR path, LPWIN32_FIND_DATAW lpFindFile,
                              BOOL bBindCtx, LPITEMIDLIST *ppidl, LPDWORD prgfInOut)
@@ -1024,7 +1024,7 @@ static HRESULT WINAPI _ILParsePathW(LPCW
  * SHSimpleIDListFromPath    [SHELL32.162]
  *
  * Creates a simple ItemIDList from a path and returns it. This function
- * does not fail on non-existent paths.
+ * does not fail on nonexistent paths.
  *
  * PARAMS
  *  path         [I]   path to parse and convert into an ItemIDList
Index: dlls/shell32/shellpath.c
===================================================================
RCS file: /var/cvs/wine/dlls/shell32/shellpath.c,v
retrieving revision 1.96
diff -u -p -r1.96 shellpath.c
--- dlls/shell32/shellpath.c	4 Nov 2004 04:54:08 -0000	1.96
+++ dlls/shell32/shellpath.c	27 Jan 2005 08:13:38 -0000
@@ -2036,7 +2036,7 @@ HRESULT WINAPI SHGetFolderLocation(
             else if (hr == HRESULT_FROM_WIN32(ERROR_FILE_NOT_FOUND))
             {
                 /* unlike SHGetFolderPath, SHGetFolderLocation in shell32
-                 * version 6.0 returns E_FAIL for non-existing paths
+                 * version 6.0 returns E_FAIL for nonexistent paths
                  */
                 hr = E_FAIL;
             }
Index: dlls/shell32/tests/shellpath.c
===================================================================
RCS file: /var/cvs/wine/dlls/shell32/tests/shellpath.c,v
retrieving revision 1.5
diff -u -p -r1.5 shellpath.c
--- dlls/shell32/tests/shellpath.c	27 Dec 2004 17:46:36 -0000	1.5
+++ dlls/shell32/tests/shellpath.c	27 Jan 2005 08:13:15 -0000
@@ -700,7 +700,7 @@ static int init(void)
 }
 
 /* Subprocess helper 1: test what happens when CSIDL_FAVORITES is set to a
- * non-existent directory.
+ * nonexistent directory.
  */
 static void testNonExistentPath1(void)
 {
Index: dlls/shell32/tests/shlfileop.c
===================================================================
RCS file: /var/cvs/wine/dlls/shell32/tests/shlfileop.c,v
retrieving revision 1.14
diff -u -p -r1.14 shlfileop.c
--- dlls/shell32/tests/shlfileop.c	6 Dec 2004 11:45:13 -0000	1.14
+++ dlls/shell32/tests/shlfileop.c	27 Jan 2005 08:13:26 -0000
@@ -306,7 +306,7 @@ void test_copy(void)
     ok(!file_exists(".\\testdir2\\test2.txt"), "The file is not copied yet\n");
     retval = SHFileOperationA(&shfo);
     if (!retval)
-      /* Win 95/NT returns success but copies only the files up to the non-existent source */
+      /* Win 95/NT returns success but copies only the files up to the nonexistent source */
       ok(file_exists(".\\testdir2\\test1.txt"), "The file is not copied\n");
     else
     {
Index: dlls/wined3d/directx.c
===================================================================
RCS file: /var/cvs/wine/dlls/wined3d/directx.c,v
retrieving revision 1.22
diff -u -p -r1.22 directx.c
--- dlls/wined3d/directx.c	31 Jan 2005 16:34:07 -0000	1.22
+++ dlls/wined3d/directx.c	31 Jan 2005 19:04:17 -0000
@@ -1296,7 +1296,7 @@ HRESULT WINAPI IWineD3DImpl_GetDeviceCap
        The following fields apply to d3d9 only
        ------------------------------------------------ */
     if (This->dxVersion > 8) {
-        FIXME("Caps support for directx9 is non-existent at the moment!\n");
+        FIXME("Caps support for directx9 is nonexistent at the moment!\n");
         pCaps->DevCaps2 = 0;
         pCaps->MaxNpatchTessellationLevel = 0;
         pCaps->MasterAdapterOrdinal = 0;
Index: dlls/winedos/ppdev.c
===================================================================
RCS file: /var/cvs/wine/dlls/winedos/ppdev.c,v
retrieving revision 1.4
diff -u -p -r1.4 ppdev.c
--- dlls/winedos/ppdev.c	30 Nov 2004 21:38:58 -0000	1.4
+++ dlls/winedos/ppdev.c	27 Jan 2005 08:11:57 -0000
@@ -147,7 +147,7 @@ char IO_pp_init(void)
 	if (ioctl (fd,PPCLAIM,0))
 	  {
 	    ERR("PPCLAIM rejected %s\n",buffer);
-	    ERR("Perhaps the device is already in use or non-existent\n");
+	    ERR("Perhaps the device is already in use or nonexistent\n");
 	    continue;
 	  }
 	if (nports > 0)
@@ -176,7 +176,7 @@ char IO_pp_init(void)
 	if (ioctl (fd,PPRELEASE,0))
 	  {
 	    ERR("PPRELEASE rejected %s\n",buffer);
-	    ERR("Perhaps the device is already in use or non-existent\n");
+	    ERR("Perhaps the device is already in use or nonexistent\n");
 	    continue;
 	  }
 	PPDeviceList[nports].devicename = malloc(sizeof(buffer)+1);
Index: documentation/configuring.sgml
===================================================================
RCS file: /var/cvs/wine/documentation/configuring.sgml,v
retrieving revision 1.52
diff -u -p -r1.52 configuring.sgml
--- documentation/configuring.sgml	6 Dec 2004 16:42:33 -0000	1.52
+++ documentation/configuring.sgml	27 Jan 2005 08:11:44 -0000
@@ -65,7 +65,7 @@
               is able to load its own internal DLLs
               (<filename>.so</filename> files) when the program
               asks for a DLL, Wine does not simulate the presence of
-              non-existent files.
+              nonexistent files.
             </para>
           </listitem>
         </itemizedlist>
Index: programs/wcmd/En.rc
===================================================================
RCS file: /var/cvs/wine/programs/wcmd/En.rc,v
retrieving revision 1.6
diff -u -p -r1.6 En.rc
--- programs/wcmd/En.rc	23 Jul 2004 23:02:09 -0000	1.6
+++ programs/wcmd/En.rc	27 Jan 2005 08:11:28 -0000
@@ -71,7 +71,7 @@ batch file.\n\
 The label which is the target of a GOTO may be up to 255 characters\n\
 long but may not include spaces (this is different from other operating\n\
 systems). If two or more identical labels exist in a batch file the\n\
-first one will always be executed. Attempting to GOTO a non-existent\n\
+first one will always be executed. Attempting to GOTO a nonexistent\n\
 label terminates the batch file execution.\n\
 \n\
 GOTO has no effect when used interactively.\n"
Index: programs/wcmd/Ru.rc
===================================================================
RCS file: /var/cvs/wine/programs/wcmd/Ru.rc,v
retrieving revision 1.3
diff -u -p -r1.3 Ru.rc
--- programs/wcmd/Ru.rc	23 Jul 2004 23:02:09 -0000	1.3
+++ programs/wcmd/Ru.rc	27 Jan 2005 08:11:21 -0000
@@ -70,7 +70,7 @@ batch file.\n\
 The label which is the target of a GOTO may be up to 255 characters\n\
 long but may not include spaces (this is different from other operating\n\
 systems). If two or more identical labels exist in a batch file the\n\
-first one will always be executed. Attempting to GOTO a non-existent\n\
+first one will always be executed. Attempting to GOTO a nonexistent\n\
 label terminates the batch file execution.\n\
 \n\
 GOTO has no effect when used interactively.\n"
Index: programs/wcmd/Si.rc
===================================================================
RCS file: /var/cvs/wine/programs/wcmd/Si.rc,v
retrieving revision 1.3
diff -u -p -r1.3 Si.rc
--- programs/wcmd/Si.rc	23 Jul 2004 23:02:09 -0000	1.3
+++ programs/wcmd/Si.rc	27 Jan 2005 08:11:12 -0000
@@ -71,7 +71,7 @@ batch file.\n\
 The label which is the target of a GOTO may be up to 255 characters\n\
 long but may not include spaces (this is different from other operating\n\
 systems). If two or more identical labels exist in a batch file the\n\
-first one will always be executed. Attempting to GOTO a non-existent\n\
+first one will always be executed. Attempting to GOTO a nonexistent\n\
 label terminates the batch file execution.\n\
 \n\
 GOTO has no effect when used interactively.\n"
Index: tools/winebuild/spec32.c
===================================================================
RCS file: /var/cvs/wine/tools/winebuild/spec32.c,v
retrieving revision 1.84
diff -u -p -r1.84 spec32.c
--- tools/winebuild/spec32.c	18 Oct 2004 21:27:52 -0000	1.84
+++ tools/winebuild/spec32.c	27 Jan 2005 08:10:58 -0000
@@ -262,7 +262,7 @@ static int output_exports( FILE *outfile
             unsigned int j, args, mask = 0;
             const char *name;
 
-            /* skip non-existent entry points */
+            /* skip nonexistent entry points */
             if (!odp) goto ignore;
             /* skip non-functions */
             if ((odp->type != TYPE_STDCALL) && (odp->type != TYPE_CDECL)) goto ignore;


More information about the wine-patches mailing list
Index: dlls/kernel/tests/path.c
===================================================================
RCS file: /var/cvs/wine/dlls/kernel/tests/path.c,v
retrieving revision 1.26
diff -u -p -r1.26 path.c
--- dlls/kernel/tests/path.c	2 Jun 2004 00:36:36 -0000	1.26
+++ dlls/kernel/tests/path.c	27 Jan 2005 08:17:23 -0000
@@ -34,9 +34,9 @@
 #define SHORTDIR "shortdir"
 #define LONGDIR "Long Directory"
 #define NONFILE_SHORT "noexist.pth"
-#define NONFILE_LONG "Non Existent File"
+#define NONFILE_LONG "NonExistent File"
 #define NONDIR_SHORT "notadir"
-#define NONDIR_LONG "Non Existent Directory"
+#define NONDIR_LONG "NonExistent Directory"
 
 #define NOT_A_VALID_DRIVE '@'
 
@@ -223,7 +223,7 @@ static void test_LongtoShortA(CHAR *test
    characters in the filename.
      'valid' indicates whether this would be an allowed filename
      'todo' indicates that wine doesn't get this right yet.
-   NOTE: We always call this routine with a non-existent filename, so
+   NOTE: We always call this routine with a nonexistent filename, so
          Get(Short|Long)PathNameA should never pass, but GetFullPathNameA
          should.
 */
@@ -413,10 +413,10 @@ static void test_CurrentDirectoryA(CHAR 
    so why check it again.
 */
   SetCurrentDirectoryA(newdir);
 /* Check that SetCurrentDirectory fails when a non-existent dir is specified */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_SHORT);
   test_setdir(newdir,tmpstr,NULL,0,"check 3");
 /* Check that SetCurrentDirectory fails for a non-existent lond directory */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_LONG);
   test_setdir(newdir,tmpstr,NULL,0,"check 4");
 /* Check that SetCurrentDirectory passes with a long directory */
@@ -640,7 +640,7 @@ static void test_PathNameA(CHAR *curdir,
   test_ValidPathA(curdir,"",tmpstr,tmpstr1,NULL,"test13");
   sprintf(tmpstr,"%s\\",LONGDIR);
   test_ValidPathA(curdir,"",tmpstr,tmpstr1,NULL,"test14");
-/* Non-existent directories */
+/* Nonexistent directories */
   sprintf(tmpstr,"%s\\",NONDIR_SHORT);
   test_ValidPathA(curdir,"",tmpstr,tmpstr1,&passfail,"test15");
   sprintf(tmpstr2,"%s\\%s",curdir_short,tmpstr);
@@ -413,10 +413,10 @@ static void test_CurrentDirectoryA(CHAR 
 */
   SetCurrentDirectoryA(newdir);
-/* Check that SetCurrentDirectory fails when a non-existent dir is specified */
+/* Check that SetCurrentDirectory fails when a nonexistent dir is specified */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_SHORT);
   test_setdir(newdir,tmpstr,NULL,0,"check 3");
@@ -413,10 +413,10 @@ static void test_CurrentDirectoryA(CHAR 
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_SHORT);
   test_setdir(newdir,tmpstr,NULL,0,"check 3");
-/* Check that SetCurrentDirectory fails for a non-existent lond directory */
+/* Check that SetCurrentDirectory fails for a nonexistent lond directory */
   sprintf(tmpstr,"%s\\%s\\%s",newdir,SHORTDIR,NONDIR_LONG);
   test_setdir(newdir,tmpstr,NULL,0,"check 4");
Index: dlls/mapi32/tests/prop.c
===================================================================
RCS file: /var/cvs/wine/dlls/mapi32/tests/prop.c,v
retrieving revision 1.7
diff -u -p -r1.7 prop.c
--- dlls/mapi32/tests/prop.c	10 Jan 2005 13:29:25 -0000	1.7
+++ dlls/mapi32/tests/prop.c	27 Jan 2005 08:18:12 -0000
@@ -636,7 +636,7 @@ static void test_PpropFindProp(void)
            ptTypes[i]);
 
         pRet = pPpropFindProp(&pvProp, 1u, i ? ptTypes[i-1] : ptTypes[i+1]);
-        ok(pRet == NULL, "PpropFindProp[%ld]: Found non-existent propery\n",
+        ok(pRet == NULL, "PpropFindProp[%ld]: Found nonexistent propery\n",
            ptTypes[i]);
     }
 
@@ -868,11 +868,11 @@ static void test_LpValFindProp(void)
            ptTypes[i]);
 
         pRet = pLpValFindProp(PROP_TAG(ptTypes[i], 0u), 1u, &pvProp);
-        ok(pRet == NULL, "LpValFindProp[%ld]: Found non-existent propery id\n",
+        ok(pRet == NULL, "LpValFindProp[%ld]: Found nonexistent propery id\n",
            ptTypes[i]);
 
         pRet = pLpValFindProp(PROP_TAG(PT_NULL, 0u), 1u, &pvProp);
-        ok(pRet == NULL, "LpValFindProp[%ld]: Found non-existent propery id/type\n",
+        ok(pRet == NULL, "LpValFindProp[%ld]: Found nonexistent propery id/type\n",
            ptTypes[i]);
 
         pRet = pLpValFindProp(PROP_TAG(PT_NULL, 1u), 1u, &pvProp);
@@ -1257,19 +1257,19 @@ static void test_IProp(void)
     tags.aulPropTag[0] = PR_RESPONSE_REQUESTED;
     sc = IPropData_DeleteProps(lpIProp, (LPSPropTagArray)&tags, &lpProbs);
     ok(sc == E_ACCESSDENIED && !lpProbs,
-       "DeleteProps(non-existent): Expected E_ACCESSDENIED null got 0x%08lX %p\n",
+       "DeleteProps(nonexistent): Expected E_ACCESSDENIED null got 0x%08lX %p\n",
        sc, lpProbs);
 
     /* Set access to read and write */
     sc = IPropData_HrSetObjAccess(lpIProp, IPROP_READWRITE);
     ok(sc == S_OK, "SetObjAcess(WRITE): Expected S_OK got 0x%08lX\n", sc);
 
     /* Delete non-existent item - No error */
     lpProbs = NULL;
     tags.aulPropTag[0] = PR_RESPONSE_REQUESTED;
     sc = IPropData_DeleteProps(lpIProp, (LPSPropTagArray)&tags, &lpProbs);
     ok(sc == S_OK && !lpProbs,
-       "DeleteProps(non-existent): Expected S_OK null got 0x%08lX %p\n",
+       "DeleteProps(nonexistent): Expected S_OK null got 0x%08lX %p\n",
        sc, lpProbs);
 
     /* Delete existing item (r/o) - No error, but lpProbs populated */
@@ -1257,19 +1257,19 @@ static void test_IProp(void)
     ok(sc == S_OK, "SetObjAcess(WRITE): Expected S_OK got 0x%08lX\n", sc);
 
-    /* Delete non-existent item - No error */
+    /* Delete nonexistent item - No error */
     lpProbs = NULL;
     tags.aulPropTag[0] = PR_RESPONSE_REQUESTED;
Index: dlls/shlwapi/tests/clist.c
===================================================================
RCS file: /var/cvs/wine/dlls/shlwapi/tests/clist.c,v
retrieving revision 1.9
diff -u -p -r1.9 clist.c
--- dlls/shlwapi/tests/clist.c	17 Jan 2005 13:42:13 -0000	1.9
+++ dlls/shlwapi/tests/clist.c	27 Jan 2005 08:13:03 -0000
@@ -381,9 +381,9 @@ static void test_CList(void)
 
   item = SHLWAPI_CLIST_items;
 
   /* Look for non-existing item in populated list */
   inserted = pSHLWAPI_22(list, 99999999);
-  ok(inserted == NULL, "found a non-existing item\n");
+  ok(inserted == NULL, "found a nonexistent item\n");
 
   while (item->ulSize)
   {
@@ -393,7 +393,7 @@ static void test_CList(void)
     item++;
   }
 
   /* Look for non-existing item in empty list */
   inserted = pSHLWAPI_22(list, 99999999);
   ok(inserted == NULL, "found an item in empty list\n");
 
@@ -381,9 +381,9 @@ static void test_CList(void)
   item = SHLWAPI_CLIST_items;
 
-  /* Look for non-existing item in populated list */
+  /* Look for nonexistent item in populated list */
   inserted = pSHLWAPI_22(list, 99999999);
@@ -393,7 +393,7 @@ static void test_CList(void)
   }
 
-  /* Look for non-existing item in empty list */
+  /* Look for nonexistent item in empty list */
   inserted = pSHLWAPI_22(list, 99999999);
   ok(inserted == NULL, "found an item in empty list\n");